@@ -7,7 +7,7 @@ function (loop.data, ...) {
   slope     <- unname(coef(ols)["x"])
   ceiling   <- p_ceiling(loop.data, slope, intercept)
   effect    <- ceiling / loop.data$scope
-  ineffs    <- p_ineffs(loop.data, intercept, slope, ceiling)
+  ineffs    <- p_ineffs(loop.data, intercept, slope)
   above     <- p_above(loop.data, slope, intercept)
   
   return(list(line=ols,
