@@ -1,5 +1,5 @@
 nca_qr <-
-function (loop.data, ...) {
+function (loop.data, mpy, cutoff, bottleneck.x) {
   x         <- loop.data$x
   y         <- loop.data$y
   # TODO Make tau configurable?
@@ -9,11 +9,12 @@ function (loop.data, ...) {
   slope     <- unname(coef(qr)["x"])
   ceiling   <- p_ceiling(loop.data, slope, intercept)
   effect    <- ceiling / loop.data$scope
-  ineffs    <- p_ineffs(loop.data, intercept, slope, ceiling)
+  ineffs    <- p_ineffs(loop.data, intercept, slope)
   above     <- p_above(loop.data, slope, intercept)
-  
+  bottleneck  <- p_bottleneck(loop.data, mpy, slope, intercept, cutoff, bottleneck.x)
+
   return(list(line=qr,
               ceiling=ceiling, slope=slope, effect=effect,
               intercept=intercept, above=above, ineffs=ineffs,
-              bottleneck=NULL))
+              bottleneck=bottleneck))
 }
\ No newline at end of file
